@@ -141,6 +141,26 @@ class DetectifyPayloadOwaspSchema(Schema):
     year = fields.Int()
 
 
+class DetectifyPayloadVulnerableVariableSchema(Schema):
+    """DetectifyPayloadVulnerableVariableSchema schema class
+    Args:
+        Schema (marshmallow.Schema): schema
+    """
+
+    uuid = fields.Str()
+    name = fields.Str()
+    method = fields.Str()
+
+
+class DetectifyPayloadVulnerableResourcesSchema(Schema):
+    """DetectifyPayloadVulnerableResourcesSchema schema class
+    Args:
+        Schema (marshmallow.Schema): schema
+    """
+
+    vulnerable_variable = fields.Nested(DetectifyPayloadVulnerableVariableSchema(many=True))
+
+
 class DetectifyPayloadSchema(Schema):
     """DetectifyPayloadSchema schema class
     Args:
@@ -163,6 +183,7 @@ class DetectifyPayloadSchema(Schema):
     highlights = fields.Nested(DetectifyPayloadHighlightsSchema(many=True))
     details = fields.Nested(DetectifyPayloadDetailsSchema(many=True))
     owasp = fields.Nested(DetectifyPayloadOwaspSchema(many=True))
+    vulnerable_resources = fields.Nested(DetectifyPayloadVulnerableResourcesSchema)
 
 
 class DetectifySchema(Schema):
